@@ -1,3 +1,4 @@
+use std::path::PathBuf;
 use crate::Profile;
 
 
@@ -16,11 +17,14 @@ pub enum Error {
 
     CredentialsNoPath,
     CredentialsNotFound,
+    CredentialsCannotRead(std::io::Error),
     CredentialsCannotRemove(std::io::Error),
 
     ProfileExists(Profile),
     ProfileNotFound(Profile),
+    ProfileCannotRead(Profile, std::io::Error),
     ProfileCannotRemove(Profile, std::io::Error),
+    ProfileCannotRename(Profile, Profile, std::io::Error),
 
     Storage(ErrorStorage),
 }
@@ -33,9 +37,12 @@ impl From<ErrorStorage> for Error {
 #[derive(Debug)]
 pub enum Success {
     List(Vec<Profile>),
+    Current(Vec<Profile>),
+    Found(PathBuf),
     Saved(Profile),
     Loaded(Profile),
     Cleared,
+    Renamed(Profile, Profile),
     Removed {
         removed: Vec<Profile>,
         errors: Vec<Error>,
